==> gitlab-tools-v0.2.0.tar.gz: gitlab-tools/bin/glt-user.sh <==
#!/bin/bash
#
# gitlab-tools:bin/glt-user.sh
#
set -u
set -o pipefail

PROJECT_HOME="$( dirname "$( dirname "$( realpath "${BASH_SOURCE[0]}" )" )" )"
declare -r PROJECT_HOME

# shellcheck disable=SC1090
source "${PROJECT_HOME}/apis/bash-common-api/bash-common-api.sh" || exit 1
# shellcheck disable=SC1090
source "${PROJECT_HOME}/bin/glt-api/user.sh" || exit 1

function usage {
  cat <<EOF
Manage GitLab users

Usage:
  ${BASH_SOURCE[0]} [options]

Action:
  -h, --help            Display help message and exit
  list                  List all users
  id ID                 Display user with given user id.
  name NAME             Display user with given user name (field name).
  username USERNAME     Display user with given user name (field username).
  search STR            Search users having STR in any field.

Options:
  -g GITLAB, --gitlab GITLAB
                        Which configuration section should be used. If not
                        defined, the default selection will be used. (python-gitlab)

EOF
}

function gitlab_search_users {
  local -r gitlab="$1"
  local -r search="$2"
  local    first='true'
  local    json=

  echo '['
  while read -r json ; do
    if json="$( grep -i "${search}" <<<"${json}" )"; then
      if [  "${first}" = 'true' ] ; then
        first='false'
      else
        echo ','
      fi
      echo "${json}"
    fi
  done < <( gitlab_get_all_users "${gitlab}" | jq -c '.[]' )
  echo ']'
}

function main {
  local action=
  local gitlab=
  local value=

  while [ $# -gt 0 ] ; do
    local param="$1"
    shift

    case "${param}" in
      '-h'|'--help')
        usage
        exit 0
        ;;

      'id'          ) action='id' ; value="$( P "$@" )" && shift ;;
      'list'        ) action='list' ;;
      'name'        ) action='name' ; value="$( P "$@" )" && shift ;;
      'search'      ) action='search' ; value="$( P "$@" )" && shift ;;
      'username'    ) action='username' ; value="$( P "$@" )" && shift ;;

      '--gitlab'    ) gitlab="$( P "$@" )" && shift ;;

      *)
        # unknown option
        echofatal "Unknown parameter '${param}'"
        usage >&2
        exit 1
        ;;
    esac
  done

  case "${action}" in
    'list')
      gitlab_get_all_users "${gitlab}" | jq .
      ;;

    'id')
      if [ -z "${value}" ] ; then
        echofatal 'id action imply user id'
        usage >&2
        exit 1
      else
        gitlab_get_user_by_userid "${gitlab}" "${value}" | jq .
      fi
      ;;

    'name')
      if [ -z "${value}" ] ; then
        echofatal 'name action imply user name'
        usage >&2
        exit 1
      else
        gitlab_get_user_by_user_name "${gitlab}" "${value}" | jq .
      fi
      ;;

    'username')
      if [ -z "${value}" ] ; then
        echofatal 'username action imply user name'
        usage >&2
        exit 1
      else
        gitlab_get_user_by_user_username "${gitlab}" "${value}" | jq .
      fi
      ;;
    'search')
      if [ -z "${value}" ] ; then
        echofatal 'search action imply search string'
        usage >&2
        exit 1
      else
        gitlab_search_users "${gitlab}" "${value}" | jq .
      fi
      ;;

    *)
      echofatal 'Missing action.'
      usage >&2
      exit 1
      ;;
  esac
}

main "$@" || exit 1

==> gitlab-tools-v0.2.1.tar.gz: gitlab-tools/bin/glt-user.sh <==
#!/bin/bash
#
# gitlab-tools:bin/glt-user.sh
#
set -u
set -o pipefail

PROJECT_HOME="$( dirname "$( dirname "$( realpath "${BASH_SOURCE[0]}" )" )" )"
declare -r PROJECT_HOME

# shellcheck disable=SC1090
source "${PROJECT_HOME}/apis/bash-common-api/bash-common-api.sh" || exit 1
# shellcheck disable=SC1090
source "${PROJECT_HOME}/bin/glt-api/user.sh" || exit 1

function usage {
  cat <<EOF
Manage GitLab users

Usage:
  ${BASH_SOURCE[0]} [options]

Action:
  -h, --help            Display help message and exit
  list                  List all users
  id ID                 Display user with given user id.
  name NAME             Display user with given user name (field name).
  username USERNAME     Display user with given user name (field username).
  search STR            Search users having STR in any field.

Options:
  -g GITLAB, --gitlab GITLAB
                        Which configuration section should be used. If not
                        defined, the default selection will be used. (python-gitlab)

EOF
}

function gitlab_search_users {
  local -r gitlab="$1"
  local -r search="$2"
  local    first='true'
  local    json=

  echo '['
  while read -r json ; do
    if json="$( grep -i "${search}" <<<"${json}" )"; then
      if [  "${first}" = 'true' ] ; then
        first='false'
      else
        echo ','
      fi
      echo "${json}"
    fi
  done < <( gitlab_get_all_users "${gitlab}" | jq -c '.[]' )
  echo ']'
}

function main {
  local action=
  local gitlab=
  local param=
  local value=

  while [ "$#" -gt 0 ] ; do
    param="$1"
    shift

    case "${param}" in
      '-h'|'--help')
        usage
        exit 0
        ;;

      'id'          ) action='id' ; value="$( P "$@" )" && shift ;;
      'list'        ) action='list' ;;
      'name'        ) action='name' ; value="$( P "$@" )" && shift ;;
      'search'      ) action='search' ; value="$( P "$@" )" && shift ;;
      'username'    ) action='username' ; value="$( P "$@" )" && shift ;;

      '--gitlab'    ) gitlab="$( P "$@" )" && shift ;;

      *)
        echofatal "Unknown option: '${param}'"
        usage >&2
        exit 1
        ;;
    esac
  done

  case "${action}" in
    'list')
      gitlab_get_all_users "${gitlab}" | jq .
      ;;

    'id')
      if [ -z "${value}" ] ; then
        echofatal 'id action imply user id'
        usage >&2
        exit 1
      else
        gitlab_get_user_by_userid "${gitlab}" "${value}" | jq .
      fi
      ;;

    'name')
      if [ -z "${value}" ] ; then
        echofatal 'name action imply user name'
        usage >&2
        exit 1
      else
        gitlab_get_user_by_user_name "${gitlab}" "${value}" | jq .
      fi
      ;;

    'username')
      if [ -z "${value}" ] ; then
        echofatal 'username action imply user name'
        usage >&2
        exit 1
      else
        gitlab_get_user_by_user_username "${gitlab}" "${value}" | jq .
      fi
      ;;
    'search')
      if [ -z "${value}" ] ; then
        echofatal 'search action imply search string'
        usage >&2
        exit 1
      else
        gitlab_search_users "${gitlab}" "${value}" | jq .
      fi
      ;;

    *)
      echofatal 'Missing action.'
      usage >&2
      exit 1
      ;;
  esac
}

main "$@" || exit 1
